@@ -42,6 +42,7 @@ from shapely.ops import transform
 from eodag.types.queryables import Queryables
 from eodag.utils import (
     DEFAULT_PROJ,
+    _deprecated,
     deepcopy,
     dict_items_recursive_apply,
     format_string,
@@ -49,10 +50,12 @@ from eodag.utils import (
     get_timestamp,
     items_recursive_apply,
     nested_pairs2dict,
+    remove_str_array_quotes,
     sanitize,
     string_to_jsonpath,
     update_nested_dict,
 )
+from eodag.utils.exceptions import ValidationError
 
 if TYPE_CHECKING:
     from shapely.geometry.base import BaseGeometry
@@ -178,6 +181,7 @@ def format_metadata(search_param: str, *args: Any, **kwargs: Any) -> str:
         - ``to_datetime_dict``: convert a datetime string to a dictionary where values are either a string or a list
         - ``get_ecmwf_time``: get the time of a datetime string in the ECMWF format
         - ``sanitize``: sanitize string
+        - ``ceda_collection_name``: generate a CEDA collection name from a string
 
     :param search_param: The string to be formatted
     :param args: (optional) Additional arguments to use in the formatting process
@@ -217,7 +221,7 @@ def format_metadata(search_param: str, *args: Any, **kwargs: Any) -> str:
                 elif value is not None:
                     converted = self.custom_converter(value)
                 else:
-                    converted = ""
+                    converted = None
                 # Clear this state variable in case the same converter is used to
                 # resolve other named arguments
                 self.custom_converter = None
@@ -372,6 +376,18 @@ def format_metadata(search_param: str, *args: Any, **kwargs: Any) -> str:
         def convert_to_geojson(value: Any) -> str:
             return geojson.dumps(value)
 
+        @staticmethod
+        def convert_to_geojson_polytope(
+            value: BaseGeometry,
+        ) -> Union[dict[Any, Any], str]:
+            # ECMWF Polytope uses non-geojson structure for features
+            if isinstance(value, Polygon):
+                return {
+                    "type": "polygon",
+                    "shape": [[y, x] for x, y in value.exterior.coords],
+                }
+            raise ValidationError("to_geojson_polytope only accepts shapely Polygon")
+
         @staticmethod
         def convert_from_ewkt(ewkt_string: str) -> Union[BaseGeometry, str]:
             """Convert EWKT (Extended Well-Known text) to shapely geometry"""
@@ -423,7 +439,7 @@ def format_metadata(search_param: str, *args: Any, **kwargs: Any) -> str:
                 return Polygon(polygon_args)
             elif len(georss) == 1 and "multisurface" in georss[0].tag.lower():
                 # Multipolygon
-                from_proj = getattr(georss[0], "attrib", {}).get("srsName", None)
+                from_proj = getattr(georss[0], "attrib", {}).get("srsName")
                 if from_proj:
                     from_proj = pyproj.CRS(from_proj)
                     to_proj = pyproj.CRS(DEFAULT_PROJ)
@@ -486,10 +502,14 @@ def format_metadata(search_param: str, *args: Any, **kwargs: Any) -> str:
 
         @staticmethod
         def convert_get_group_name(string: str, pattern: str) -> str:
+            sanitized_pattern = pattern.replace(" ", "_SPACE_")
             try:
-                match = re.search(pattern, str(string))
+                match = re.search(sanitized_pattern, str(string))
                 if match:
-                    return match.lastgroup or NOT_AVAILABLE
+                    if result := match.lastgroup:
+                        return result.replace("_SPACE_", " ")
+                    else:
+                        return NOT_AVAILABLE
             except AttributeError:
                 pass
             logger.warning(
@@ -503,12 +523,20 @@ def format_metadata(search_param: str, *args: Any, **kwargs: Any) -> str:
                 value = MetadataFormatter.convert_to_geojson(value)
             elif not isinstance(value, str):
                 raise TypeError(
-                    f"convert_replace_str expects a string or a dict (apply to_geojson). Got {type(value)}"
+                    f"convert_replace_str expects a string or a dict (apply to_geojson). Got {type(value)}: {value}"
                 )
 
             old, new = ast.literal_eval(args)
             return re.sub(old, new, value)
 
+        @staticmethod
+        def convert_ceda_collection_name(value: str) -> str:
+            data_regex = re.compile(r"/data/(?P<name>.+?)/?$")
+            match = data_regex.search(value)
+            if match:
+                return match.group("name").replace("/", "_").upper()
+            return "NOT_AVAILABLE"
+
         @staticmethod
         def convert_recursive_sub_str(
             input_obj: Union[dict[Any, Any], list[Any]], args: str
@@ -613,6 +641,10 @@ def format_metadata(search_param: str, *args: Any, **kwargs: Any) -> str:
                 return NOT_AVAILABLE
 
         @staticmethod
+        @_deprecated(
+            reason="Method that was used in previous wekeo provider configuration, but not used anymore",
+            version="3.7.1",
+        )
         def convert_split_id_into_s1_params(product_id: str) -> dict[str, str]:
             parts: list[str] = re.split(r"_(?!_)", product_id)
             if len(parts) < 9:
@@ -665,6 +697,10 @@ def format_metadata(search_param: str, *args: Any, **kwargs: Any) -> str:
             return params
 
         @staticmethod
+        @_deprecated(
+            reason="Method that was used in previous wekeo provider configuration, but not used anymore",
+            version="3.7.1",
+        )
         def convert_split_id_into_s5p_params(product_id: str) -> dict[str, str]:
             parts: list[str] = re.split(r"_(?!_)", product_id)
             params = {
@@ -683,6 +719,10 @@ def format_metadata(search_param: str, *args: Any, **kwargs: Any) -> str:
             return params
 
         @staticmethod
+        @_deprecated(
+            reason="Method that was used in previous wekeo provider configuration, but not used anymore",
+            version="3.7.1",
+        )
         def convert_split_cop_dem_id(product_id: str) -> list[int]:
             parts = product_id.split("_")
             lattitude = parts[3]
@@ -1029,8 +1069,8 @@ def properties_from_json(
     if not discovery_config:
         discovery_config = {}
 
-    discovery_pattern = discovery_config.get("metadata_pattern", None)
-    discovery_path = discovery_config.get("metadata_path", None)
+    discovery_pattern = discovery_config.get("metadata_pattern")
+    discovery_path = discovery_config.get("metadata_path")
     if discovery_pattern and discovery_path:
         discovery_jsonpath = string_to_jsonpath(discovery_path)
         discovered_properties = (
@@ -1214,8 +1254,8 @@ def properties_from_xml(
     # adds missing discovered properties
     if not discovery_config:
         discovery_config = {}
-    discovery_pattern = discovery_config.get("metadata_pattern", None)
-    discovery_path = discovery_config.get("metadata_path", None)
+    discovery_pattern = discovery_config.get("metadata_pattern")
+    discovery_path = discovery_config.get("metadata_path")
     if discovery_pattern and discovery_path:
         discovered_properties = root.xpath(
             discovery_path,
@@ -1285,7 +1325,10 @@ def mtd_cfg_as_conversion_and_querypath(
 
 
 def format_query_params(
-    product_type: str, config: PluginConfig, query_dict: dict[str, Any]
+    product_type: str,
+    config: PluginConfig,
+    query_dict: dict[str, Any],
+    error_context: str = "",
 ) -> dict[str, Any]:
     """format the search parameters to query parameters"""
     if "raise_errors" in query_dict.keys():
@@ -1298,10 +1341,26 @@ def format_query_params(
         **config.products.get(product_type, {}).get("metadata_mapping", {}),
     )
 
+    # Raise error if non-queryables parameters are used and raise_mtd_discovery_error configured
+    if (
+        raise_mtd_discovery_error := config.products.get(product_type, {})
+        .get("discover_metadata", {})
+        .get("raise_mtd_discovery_error")
+    ) is None:
+        raise_mtd_discovery_error = getattr(config, "discover_metadata", {}).get(
+            "raise_mtd_discovery_error", False
+        )
+
     query_params: dict[str, Any] = {}
     # Get all the search parameters that are recognised as queryables by the
     # provider (they appear in the queryables dictionary)
-    queryables = _get_queryables(query_dict, config, product_type_metadata_mapping)
+    queryables = _get_queryables(
+        query_dict,
+        config,
+        product_type_metadata_mapping,
+        raise_mtd_discovery_error,
+        error_context,
+    )
 
     for eodag_search_key, provider_search_key in queryables.items():
         user_input = query_dict[eodag_search_key]
@@ -1317,6 +1376,11 @@ def format_query_params(
                     # retrieve values from hashes where keys are given in the param
                     if "}[" in formatted_query_param:
                         formatted_query_param = _resolve_hashes(formatted_query_param)
+                    # remove quotes around arrays
+                    formatted_query_param = remove_str_array_quotes(
+                        formatted_query_param
+                    )
+
                     # json query string (for POST request)
                     update_nested_dict(
                         query_params,
@@ -1433,6 +1497,8 @@ def _get_queryables(
     search_params: dict[str, Any],
     config: PluginConfig,
     metadata_mapping: dict[str, Any],
+    raise_mtd_discovery_error: bool,
+    error_context: str,
 ) -> dict[str, Any]:
     """Retrieve the metadata mappings that are query-able"""
     logger.debug("Retrieving queryable metadata from metadata_mapping")
@@ -1440,6 +1506,13 @@ def _get_queryables(
     for eodag_search_key, user_input in search_params.items():
         if user_input is not None:
             md_mapping = metadata_mapping.get(eodag_search_key, (None, NOT_MAPPED))
+            # raise an error when a query param not allowed by the provider is found
+            if not isinstance(md_mapping, list) and raise_mtd_discovery_error:
+                raise ValidationError(
+                    "Search parameters which are not queryable are disallowed for this product type on this provider: "
+                    f"please remove '{eodag_search_key}' from your search parameters. {error_context}",
+                    {eodag_search_key},
+                )
             _, md_value = md_mapping
             # query param from defined metadata_mapping
             if md_mapping is not None and isinstance(md_mapping, list):
@@ -1519,7 +1592,7 @@ def get_provider_queryable_path(
     :param metadata_mapping: metadata-mapping configuration
     :returns: EODAG configured queryable path or None
     """
-    parameter_conf = metadata_mapping.get(queryable, None)
+    parameter_conf = metadata_mapping.get(queryable)
     if isinstance(parameter_conf, list):
         return parameter_conf[0]
     else:
