@@ -46,6 +46,7 @@ from jsonpath_ng import JSONPath
 from eodag.api.product.metadata_mapping import mtd_cfg_as_conversion_and_querypath
 from eodag.utils import (
     HTTP_REQ_TIMEOUT,
+    STAC_SEARCH_PLUGINS,
     USER_AGENT,
     cached_yaml_load,
     cached_yaml_load_all,
@@ -194,12 +195,24 @@ class ProviderConfig(yaml.YAMLObject):
             },
         )
         for key in PLUGINS_TOPICS_KEYS:
-            current_value: Optional[dict[str, Any]] = getattr(self, key, None)
+            current_value: Optional[PluginConfig] = getattr(self, key, None)
             mapping_value = mapping.get(key, {})
             if current_value is not None:
                 current_value.update(mapping_value)
             elif mapping_value:
-                setattr(self, key, PluginConfig.from_mapping(mapping_value))
+                try:
+                    setattr(self, key, PluginConfig.from_mapping(mapping_value))
+                except ValidationError as e:
+                    logger.warning(
+                        (
+                            "Could not add %s Plugin config to %s configuration: %s. "
+                            "Try updating existing %s Plugin configs instead."
+                        ),
+                        key,
+                        self.name,
+                        str(e),
+                        ", ".join([k for k in PLUGINS_TOPICS_KEYS if hasattr(self, k)]),
+                    )
 
 
 class PluginConfig(yaml.YAMLObject):
@@ -256,9 +269,11 @@ class PluginConfig(yaml.YAMLObject):
         #: Metadata regex pattern used for discovery in search result properties
         metadata_pattern: str
         #: Configuration/template that will be used to query for a discovered parameter
-        search_param: str
+        search_param: str | dict[str, Any]
         #: Path to the metadata in search result
         metadata_path: str
+        #: Whether an error must be raised when using a search parameter which is not queryable or not
+        raise_mtd_discovery_error: bool
 
     class DiscoverProductTypes(TypedDict, total=False):
         """Configuration for product types discovery"""
@@ -292,7 +307,8 @@ class PluginConfig(yaml.YAMLObject):
         single_collection_fetch_url: str
         #: Query string to be added to the fetch_url to filter for a collection
         single_collection_fetch_qs: str
-        #: Mapping for product type metadata returned by the endpoint given in single_collection_fetch_url
+        #: Mapping for product type metadata returned by the endpoint given in single_collection_fetch_url. If ``ID``
+        #: is redefined in this mapping, it will replace ``generic_product_type_id`` value
         single_product_type_parsable_metadata: dict[str, str]
 
     class DiscoverQueryables(TypedDict, total=False):
@@ -437,6 +453,11 @@ class PluginConfig(yaml.YAMLObject):
     discover_queryables: PluginConfig.DiscoverQueryables
     #: :class:`~eodag.plugins.search.base.Search` The mapping between eodag metadata and the plugin specific metadata
     metadata_mapping: dict[str, Union[str, list[str]]]
+    #: :class:`~eodag.plugins.search.base.Search` :attr:`~eodag.config.PluginConfig.metadata_mapping` got from the given
+    #: product type
+    metadata_mapping_from_product: str
+    #: :class:`~eodag.plugins.search.base.Search` A mapping for the metadata of individual assets
+    assets_mapping: dict[str, dict[str, Any]]
     #: :class:`~eodag.plugins.search.base.Search` Parameters to remove from queryables
     remove_from_queryables: list[str]
     #: :class:`~eodag.plugins.search.base.Search` Parameters to be passed as is in the search url query string
@@ -628,6 +649,10 @@ class PluginConfig(yaml.YAMLObject):
     #: :class:`~eodag.plugins.authentication.token_exchange.OIDCTokenExchangeAuth`
     #: Identifies the issuer of the `subject_token`
     subject_issuer: str
+    #: :class:`~eodag.plugins.authentication.token.TokenAuth`
+    #: :class:`~eodag.plugins.authentication.openid_connect.OIDCRefreshTokenBase`
+    #: Safety buffer to prevent token rejection from unexpected expiry between validity check and request.
+    token_expiration_margin: int
     #: :class:`~eodag.plugins.authentication.token_exchange.OIDCTokenExchangeAuth`
     #: Audience that the token ID is intended for. :attr:`~eodag.config.PluginConfig.client_id` of the Relying Party
     audience: str
@@ -648,6 +673,7 @@ class PluginConfig(yaml.YAMLObject):
     @classmethod
     def from_mapping(cls, mapping: dict[str, Any]) -> PluginConfig:
         """Build a :class:`~eodag.config.PluginConfig` from a mapping"""
+        cls.validate(tuple(mapping.keys()))
         c = cls()
         c.__dict__.update(mapping)
         return c
@@ -657,7 +683,7 @@ class PluginConfig(yaml.YAMLObject):
         """Validate a :class:`~eodag.config.PluginConfig`"""
         if "type" not in config_keys:
             raise ValidationError(
-                "A Plugin config must specify the Plugin it configures"
+                "A Plugin config must specify the type of Plugin it configures"
             )
 
     def update(self, mapping: Optional[dict[Any, Any]]) -> None:
@@ -689,6 +715,8 @@ def load_default_config() -> dict[str, ProviderConfig]:
 def load_config(config_path: str) -> dict[str, ProviderConfig]:
     """Load the providers configuration into a dictionary from a given file
 
+    If EODAG_PROVIDERS_WHITELIST is set, only load listed providers.
+
     :param config_path: The path to the provider config file
     :returns: The default provider's configuration
     """
@@ -701,10 +729,23 @@ def load_config(config_path: str) -> dict[str, ProviderConfig]:
     except yaml.parser.ParserError as e:
         logger.error("Unable to load configuration")
         raise e
+
     stac_provider_config = load_stac_provider_config()
+
+    whitelist_env = os.getenv("EODAG_PROVIDERS_WHITELIST")
+    whitelist = None
+    if whitelist_env:
+        whitelist = {provider for provider in whitelist_env.split(",")}
+        logger.info("Using providers whitelist: %s", ", ".join(whitelist))
+
     for provider_config in providers_configs:
+        if provider_config is None or (
+            whitelist and provider_config.name not in whitelist
+        ):
+            continue
         provider_config_init(provider_config, stac_provider_config)
         config[provider_config.name] = provider_config
+
     return config
 
 
@@ -785,12 +826,7 @@ def provider_config_init(
         if (
             stac_search_default_conf is not None
             and provider_config.search
-            and provider_config.search.type
-            in [
-                "StacSearch",
-                "StacListAssets",
-                "StaticStacSearch",
-            ]
+            and provider_config.search.type in STAC_SEARCH_PLUGINS
         ):
             # search config set to stac defaults overriden with provider config
             per_provider_stac_provider_config = deepcopy(stac_search_default_conf)
@@ -803,7 +839,9 @@ def provider_config_init(
         pass
 
 
-def override_config_from_file(config: dict[str, Any], file_path: str) -> None:
+def override_config_from_file(
+    config: dict[str, ProviderConfig], file_path: str
+) -> None:
     """Override a configuration with the values in a file
 
     :param config: An eodag providers configuration dictionary
@@ -818,10 +856,11 @@ def override_config_from_file(config: dict[str, Any], file_path: str) -> None:
         except yaml.parser.ParserError as e:
             logger.error("Unable to load user configuration file")
             raise e
+
     override_config_from_mapping(config, config_in_file)
 
 
-def override_config_from_env(config: dict[str, Any]) -> None:
+def override_config_from_env(config: dict[str, ProviderConfig]) -> None:
     """Override a configuration with environment variables values
 
     :param config: An eodag providers configuration dictionary
@@ -851,7 +890,7 @@ def override_config_from_env(config: dict[str, Any]) -> None:
         iter_parts = iter(parts)
         env_type = get_type_hints(PluginConfig).get(next(iter_parts, ""), str)
         child_env_type = (
-            get_type_hints(env_type).get(next(iter_parts, ""), None)
+            get_type_hints(env_type).get(next(iter_parts, ""))
             if isclass(env_type)
             else None
         )
@@ -892,16 +931,25 @@ def override_config_from_env(config: dict[str, Any]) -> None:
 
 
 def override_config_from_mapping(
-    config: dict[str, Any], mapping: dict[str, Any]
+    config: dict[str, ProviderConfig], mapping: dict[str, Any]
 ) -> None:
-    """Override a configuration with the values in a mapping
+    """Override a configuration with the values in a mapping.
+
+    If the environment variable ``EODAG_PROVIDERS_WHITELIST`` is set (as a comma-separated list of provider names),
+    only the listed providers will be used from the mapping. All other providers in the mapping will be ignored.
 
     :param config: An eodag providers configuration dictionary
     :param mapping: The mapping containing the values to be overriden
     """
+    whitelist_env = os.getenv("EODAG_PROVIDERS_WHITELIST")
+    whitelist = None
+    if whitelist_env:
+        whitelist = {provider for provider in whitelist_env.split(",")}
+
     for provider, new_conf in mapping.items():
         # check if metada-mapping as already been built as jsonpath in providers_config
-        if not isinstance(new_conf, dict):
+        # or provider not in whitelist
+        if not isinstance(new_conf, dict) or (whitelist and provider not in whitelist):
             continue
         new_conf_search = new_conf.get("search", {}) or {}
         new_conf_api = new_conf.get("api", {}) or {}
@@ -930,7 +978,7 @@ def override_config_from_mapping(
                 )
 
         # try overriding conf
-        old_conf: Optional[dict[str, Any]] = config.get(provider)
+        old_conf: Optional[ProviderConfig] = config.get(provider)
         if old_conf is not None:
             old_conf.update(new_conf)
         else:
@@ -961,7 +1009,7 @@ def merge_configs(config: dict[str, Any], other_config: dict[str, Any]) -> None:
     other_config = dict(config, **other_config)
 
     for provider, new_conf in other_config.items():
-        old_conf = config.get(provider, None)
+        old_conf = config.get(provider)
 
         if old_conf:
             # update non-objects values
