@@ -28,7 +28,16 @@ from email.message import Message
 from itertools import chain
 from json import JSONDecodeError
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Iterator, Optional, TypedDict, Union, cast
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Iterator,
+    Literal,
+    Optional,
+    TypedDict,
+    Union,
+    cast,
+)
 from urllib.parse import parse_qs, urlparse
 
 import geojson
@@ -77,6 +86,7 @@ from eodag.utils.exceptions import (
 )
 
 if TYPE_CHECKING:
+    from jsonpath_ng import JSONPath
     from requests import Response
 
     from eodag.api.product import Asset, EOProduct  # type: ignore
@@ -538,7 +548,9 @@ class HTTPDownload(Download):
                     else {}
                 )
                 if result_entry:
-                    entry_jsonpath = string_to_jsonpath(result_entry, force=True)
+                    entry_jsonpath: JSONPath = string_to_jsonpath(
+                        result_entry, force=True
+                    )
                     json_response = entry_jsonpath.find(json_response)
                     raise NotImplementedError(
                         'result_entry in config.on_success is not yet supported for result_type "json"'
@@ -611,7 +623,7 @@ class HTTPDownload(Download):
         # download assets if exist instead of remote_location
         if len(product.assets) > 0 and (
             not getattr(self.config, "ignore_assets", False)
-            or kwargs.get("asset", None) is not None
+            or kwargs.get("asset") is not None
         ):
             try:
                 fs_path = self._download_assets(
@@ -622,11 +634,11 @@ class HTTPDownload(Download):
                     progress_callback,
                     **kwargs,
                 )
-                if kwargs.get("asset", None) is None:
+                if kwargs.get("asset") is None:
                     product.location = path_to_uri(fs_path)
                 return fs_path
             except NotAvailableError as e:
-                if kwargs.get("asset", None) is not None:
+                if kwargs.get("asset") is not None:
                     raise NotAvailableError(e).with_traceback(e.__traceback__)
                 else:
                     pass
@@ -661,6 +673,9 @@ class HTTPDownload(Download):
 
                 if is_empty:
                     raise DownloadError(f"product {product.properties['id']} is empty")
+                else:
+                    # make sure storage status is online
+                    product.properties["storageStatus"] = ONLINE_STATUS
 
                 return path
             else:
@@ -718,7 +733,7 @@ class HTTPDownload(Download):
 
     def _check_product_filename(self, product: EOProduct) -> str:
         filename = None
-        asset_content_disposition = self.stream.headers.get("content-disposition", None)
+        asset_content_disposition = self.stream.headers.get("content-disposition")
         if asset_content_disposition:
             filename = cast(
                 Optional[str],
@@ -739,7 +754,8 @@ class HTTPDownload(Download):
         self,
         product: EOProduct,
         auth: Optional[Union[AuthBase, S3SessionKwargs]] = None,
-        progress_callback: Optional[ProgressCallback] = None,
+        byte_range: tuple[Optional[int], Optional[int]] = (None, None),
+        compress: Literal["zip", "raw", "auto"] = "auto",
         wait: float = DEFAULT_DOWNLOAD_WAIT,
         timeout: float = DEFAULT_DOWNLOAD_TIMEOUT,
         **kwargs: Unpack[DownloadConf],
@@ -769,11 +785,11 @@ class HTTPDownload(Download):
             or kwargs.get("asset") is not None
         ):
             try:
-                assets_values = product.assets.get_values(kwargs.get("asset", None))
+                assets_values = product.assets.get_values(kwargs.get("asset"))
                 chunks_tuples = self._stream_download_assets(
                     product,
                     auth,
-                    progress_callback,
+                    None,
                     assets_values=assets_values,
                     **kwargs,
                 )
@@ -786,7 +802,7 @@ class HTTPDownload(Download):
                     assets_values[0].headers[
                         "content-disposition"
                     ] = f"attachment; filename={assets_values[0].filename}"
-                    if assets_values[0].get("type", None):
+                    if assets_values[0].get("type"):
                         assets_values[0].headers["content-type"] = assets_values[0][
                             "type"
                         ]
@@ -814,14 +830,12 @@ class HTTPDownload(Download):
                         },
                     )
             except NotAvailableError as e:
-                if kwargs.get("asset", None) is not None:
+                if kwargs.get("asset") is not None:
                     raise NotAvailableError(e).with_traceback(e.__traceback__)
                 else:
                     pass
 
-        chunk_iterator = self._stream_download(
-            product, auth, progress_callback, **kwargs
-        )
+        chunk_iterator = self._stream_download(product, auth, None, **kwargs)
 
         # start reading chunks to set product.headers
         try:
@@ -903,7 +917,7 @@ class HTTPDownload(Download):
             self._order(product=product, auth=auth)
 
         if (
-            product.properties.get("orderStatusLink", None)
+            product.properties.get("orderStatusLink")
             and product.properties.get("storageStatus") != ONLINE_STATUS
         ):
             self._order_status(product=product, auth=auth)
@@ -1151,7 +1165,7 @@ class HTTPDownload(Download):
                     if not getattr(asset, "filename", None):
                         # try getting filename in GET header if was not found in HEAD result
                         asset_content_disposition = stream.headers.get(
-                            "content-disposition", None
+                            "content-disposition"
                         )
                         if asset_content_disposition:
                             asset.filename = cast(
@@ -1203,7 +1217,7 @@ class HTTPDownload(Download):
         if not assets_urls:
             raise NotAvailableError("No assets available for %s" % product)
 
-        assets_values = product.assets.get_values(kwargs.get("asset", None))
+        assets_values = product.assets.get_values(kwargs.get("asset"))
 
         chunks_tuples = self._stream_download_assets(
             product, auth, progress_callback, assets_values=assets_values, **kwargs
@@ -1289,7 +1303,7 @@ class HTTPDownload(Download):
         if flatten_top_dirs:
             flatten_top_directories(fs_dir_path)
 
-        if kwargs.get("asset", None) is None:
+        if kwargs.get("asset") is None:
             # save hash/record file
             with open(record_filename, "w") as fh:
                 fh.write(product.remote_location)
