@@ -25,6 +25,7 @@ from pydantic.fields import Field, FieldInfo
 
 from eodag.api.product.metadata_mapping import (
     DEFAULT_METADATA_MAPPING,
+    NOT_AVAILABLE,
     NOT_MAPPED,
     mtd_cfg_as_conversion_and_querypath,
 )
@@ -38,6 +39,7 @@ from eodag.utils import (
     copy_deepcopy,
     deepcopy,
     format_dict_items,
+    string_to_jsonpath,
     update_nested_dict,
 )
 from eodag.utils.exceptions import ValidationError
@@ -158,10 +160,6 @@ class Search(PluginTopic):
         :returns: The product type definition parameters
         """
         if product_type in self.config.products.keys():
-            logger.debug(
-                "Getting provider product type definition parameters for %s",
-                product_type,
-            )
             return self.config.products[product_type]
         elif GENERIC_PRODUCT_TYPE in self.config.products.keys():
             logger.debug(
@@ -224,7 +222,7 @@ class Search(PluginTopic):
         # it will complete the query string or body once metadata mapping will be done
         sort_by_arg_tmp = kwargs.pop("sort_by", None)
         sort_by_arg = sort_by_arg_tmp or getattr(self.config, "sort", {}).get(
-            "sort_by_default", None
+            "sort_by_default"
         )
         if not sort_by_arg_tmp and sort_by_arg:
             logger.info(
@@ -255,7 +253,7 @@ class Search(PluginTopic):
         for eodag_sort_by_tuple in sort_by_arg:
             eodag_sort_param = eodag_sort_by_tuple[0]
             provider_sort_param = self.config.sort["sort_param_mapping"].get(
-                eodag_sort_param, None
+                eodag_sort_param
             )
             if not provider_sort_param:
                 joined_eodag_params_to_map = ", ".join(
@@ -275,7 +273,8 @@ class Search(PluginTopic):
             if eodag_sort_order[:3] != "ASC" and eodag_sort_order[:3] != "DES":
                 raise ValidationError(
                     "Sorting order is invalid: it must be set to 'ASC' (ASCENDING) or "
-                    f"'DESC' (DESCENDING), got '{eodag_sort_order}' with '{eodag_sort_param}' instead"
+                    f"'DESC' (DESCENDING), got '{eodag_sort_order}' with '{eodag_sort_param}' instead",
+                    {eodag_sort_param},
                 )
             eodag_sort_order = eodag_sort_order[:3]
 
@@ -296,14 +295,14 @@ class Search(PluginTopic):
                     raise ValidationError(
                         f"'{eodag_sort_param}' parameter is called several times to sort results with different "
                         "sorting orders. Please set it to only one ('ASC' (ASCENDING) or 'DESC' (DESCENDING))",
-                        set([eodag_sort_param]),
+                        {eodag_sort_param},
                     )
             provider_sort_by_tuples_used.append(provider_sort_by_tuple)
 
             # TODO: move this code block to the top of this method when search args model validation is embeded
             # check if the limit number of sorting parameter(s) is respected with this sorting parameter
             if (
-                self.config.sort.get("max_sort_params", None)
+                self.config.sort.get("max_sort_params")
                 and len(provider_sort_by_tuples_used)
                 > self.config.sort["max_sort_params"]
             ):
@@ -369,6 +368,9 @@ class Search(PluginTopic):
             if not product_type
             else ""
         )
+        discover_metadata = getattr(self.config, "discover_metadata", {})
+        auto_discovery = discover_metadata.get("auto_discovery", False)
+
         if product_type or getattr(self.config, "discover_queryables", {}).get(
             "fetch_url", ""
         ):
@@ -376,6 +378,7 @@ class Search(PluginTopic):
                 self.config.product_type_config = product_type_configs[product_type]
             queryables = self._get_product_type_queryables(product_type, alias, filters)
             queryables.additional_information = additional_info
+            queryables.additional_properties = auto_discovery
 
             return queryables
         else:
@@ -390,7 +393,7 @@ class Search(PluginTopic):
                     Queryables.model_fields.get(k, Field(None)), "default", None
                 )
             return QueryablesDict(
-                additional_properties=True,
+                additional_properties=auto_discovery,
                 additional_information=additional_info,
                 **all_queryables,
             )
@@ -434,3 +437,35 @@ class Search(PluginTopic):
             ):
                 queryables[k] = v
         return queryables
+
+    def get_assets_from_mapping(self, provider_item: dict[str, Any]) -> dict[str, Any]:
+        """
+        Create assets based on the assets_mapping in the provider's config
+        and an item returned by the provider
+
+        :param provider_item: dict of item properties returned by the provider
+        :returns: dict containing the asset metadata
+        """
+        assets_mapping = getattr(self.config, "assets_mapping", None)
+        if not assets_mapping:
+            return {}
+        assets = {}
+        for key, values in assets_mapping.items():
+            asset_href = values.get("href")
+            if not asset_href:
+                logger.warning(
+                    "asset mapping %s skipped because no href is available", key
+                )
+                continue
+            json_url_path = string_to_jsonpath(asset_href)
+            if isinstance(json_url_path, str):
+                url_path = json_url_path
+            else:
+                url_match = json_url_path.find(provider_item)
+                if len(url_match) == 1:
+                    url_path = url_match[0].value
+                else:
+                    url_path = NOT_AVAILABLE
+            assets[key] = deepcopy(values)
+            assets[key]["href"] = url_path
+        return assets
