@@ -35,9 +35,11 @@ from typing import (
 from urllib.error import URLError
 from urllib.parse import (
     parse_qsl,
+    quote,
     quote_plus,
     unquote,
     unquote_plus,
+    urlencode,
     urlparse,
     urlunparse,
 )
@@ -70,6 +72,7 @@ from eodag.api.search_result import RawSearchResult
 from eodag.plugins.search import PreparedSearch
 from eodag.plugins.search.base import Search
 from eodag.types import json_field_definition_to_python, model_fields_to_annotated
+from eodag.types.queryables import Queryables
 from eodag.types.search_args import SortByList
 from eodag.utils import (
     DEFAULT_SEARCH_TIMEOUT,
@@ -80,14 +83,13 @@ from eodag.utils import (
     REQ_RETRY_TOTAL,
     USER_AGENT,
     _deprecated,
+    copy_deepcopy,
     deepcopy,
     dict_items_recursive_apply,
     format_dict_items,
     get_ssl_context,
-    quote,
     string_to_jsonpath,
     update_nested_dict,
-    urlencode,
 )
 from eodag.utils.exceptions import (
     AuthenticationError,
@@ -313,31 +315,27 @@ class QueryStringSearch(Search):
             and "next_page_url_key_path" in self.config.pagination
         ):
             self.config.pagination["next_page_url_key_path"] = string_to_jsonpath(
-                self.config.pagination.get("next_page_url_key_path", None)
+                self.config.pagination.get("next_page_url_key_path")
             )
         if (
             self.config.result_type == "json"
             and "next_page_query_obj_key_path" in self.config.pagination
         ):
             self.config.pagination["next_page_query_obj_key_path"] = string_to_jsonpath(
-                self.config.pagination.get("next_page_query_obj_key_path", None)
+                self.config.pagination.get("next_page_query_obj_key_path")
             )
         if (
             self.config.result_type == "json"
             and "next_page_merge_key_path" in self.config.pagination
         ):
             self.config.pagination["next_page_merge_key_path"] = string_to_jsonpath(
-                self.config.pagination.get("next_page_merge_key_path", None)
+                self.config.pagination.get("next_page_merge_key_path")
             )
 
         # parse jsonpath on init: product types discovery
         if (
-            getattr(self.config, "discover_product_types", {}).get(
-                "results_entry", None
-            )
-            and getattr(self.config, "discover_product_types", {}).get(
-                "result_type", None
-            )
+            getattr(self.config, "discover_product_types", {}).get("results_entry")
+            and getattr(self.config, "discover_product_types", {}).get("result_type")
             == "json"
         ):
             self.config.discover_product_types["results_entry"] = string_to_jsonpath(
@@ -378,8 +376,8 @@ class QueryStringSearch(Search):
 
         # parse jsonpath on init: queryables discovery
         if (
-            getattr(self.config, "discover_queryables", {}).get("results_entry", None)
-            and getattr(self.config, "discover_queryables", {}).get("result_type", None)
+            getattr(self.config, "discover_queryables", {}).get("results_entry")
+            and getattr(self.config, "discover_queryables", {}).get("result_type")
             == "json"
         ):
             self.config.discover_queryables["results_entry"] = string_to_jsonpath(
@@ -388,36 +386,48 @@ class QueryStringSearch(Search):
 
         # parse jsonpath on init: product type specific metadata-mapping
         for product_type in self.config.products.keys():
-            if "metadata_mapping" in self.config.products[product_type].keys():
-                self.config.products[product_type][
-                    "metadata_mapping"
-                ] = mtd_cfg_as_conversion_and_querypath(
-                    self.config.products[product_type]["metadata_mapping"]
-                )
+
+            product_type_metadata_mapping = {}
+            # product-type specific metadata-mapping
+            if any(
+                mm in self.config.products[product_type].keys()
+                for mm in ("metadata_mapping", "metadata_mapping_from_product")
+            ):
                 # Complete and ready to use product type specific metadata-mapping
                 product_type_metadata_mapping = deepcopy(self.config.metadata_mapping)
 
-                # update config using provider product type definition metadata_mapping
-                # from another product
-                other_product_for_mapping = cast(
-                    str,
-                    self.config.products[product_type].get(
-                        "metadata_mapping_from_product", ""
-                    ),
+            # metadata_mapping from another product
+            if other_product_for_mapping := self.config.products[product_type].get(
+                "metadata_mapping_from_product"
+            ):
+                other_product_type_def_params = self.get_product_type_def_params(
+                    other_product_for_mapping,
                 )
-                if other_product_for_mapping:
-                    other_product_type_def_params = self.get_product_type_def_params(
-                        other_product_for_mapping,
-                    )
+                # parse mapping to apply
+                if other_product_type_mtd_mapping := other_product_type_def_params.get(
+                    "metadata_mapping", {}
+                ):
                     other_product_type_mtd_mapping = (
                         mtd_cfg_as_conversion_and_querypath(
                             other_product_type_def_params.get("metadata_mapping", {})
                         )
                     )
-                    # updated mapping at the end
-                    for metadata, mapping in other_product_type_mtd_mapping.items():
-                        product_type_metadata_mapping.pop(metadata, None)
-                        product_type_metadata_mapping[metadata] = mapping
+                else:
+                    msg = f"Cannot reuse empty metadata_mapping from {other_product_for_mapping} for {product_type}"
+                    raise MisconfiguredError(msg)
+                # update mapping
+                for metadata, mapping in other_product_type_mtd_mapping.items():
+                    product_type_metadata_mapping.pop(metadata, None)
+                    product_type_metadata_mapping[metadata] = mapping
+
+            # metadata_mapping from current product
+            if "metadata_mapping" in self.config.products[product_type].keys():
+                # parse mapping to apply
+                self.config.products[product_type][
+                    "metadata_mapping"
+                ] = mtd_cfg_as_conversion_and_querypath(
+                    self.config.products[product_type]["metadata_mapping"]
+                )
 
                 # from current product, updated mapping at the end
                 for metadata, mapping in self.config.products[product_type][
@@ -426,6 +436,7 @@ class QueryStringSearch(Search):
                     product_type_metadata_mapping.pop(metadata, None)
                     product_type_metadata_mapping[metadata] = mapping
 
+            if product_type_metadata_mapping:
                 self.config.products[product_type][
                     "metadata_mapping"
                 ] = product_type_metadata_mapping
@@ -616,6 +627,26 @@ class QueryStringSearch(Search):
                                 generic_product_type_id
                             ].update(collection_data)
 
+                            # update product type id if needed
+                            if collection_data_id := collection_data.get("ID"):
+                                if generic_product_type_id != collection_data_id:
+                                    logger.debug(
+                                        "Rename %s product type to %s",
+                                        generic_product_type_id,
+                                        collection_data_id,
+                                    )
+                                    conf_update_dict["providers_config"][
+                                        collection_data_id
+                                    ] = conf_update_dict["providers_config"].pop(
+                                        generic_product_type_id
+                                    )
+                                    conf_update_dict["product_types_config"][
+                                        collection_data_id
+                                    ] = conf_update_dict["product_types_config"].pop(
+                                        generic_product_type_id
+                                    )
+                                    generic_product_type_id = collection_data_id
+
                         # update keywords
                         keywords_fields = [
                             "instrument",
@@ -729,7 +760,7 @@ class QueryStringSearch(Search):
         :param prep: Object collecting needed information for search.
         """
         count = prep.count
-        product_type = kwargs.get("productType", prep.product_type)
+        product_type = cast(str, kwargs.get("productType", prep.product_type))
         if product_type == GENERIC_PRODUCT_TYPE:
             logger.warning(
                 "GENERIC_PRODUCT_TYPE is not a real product_type and should only be used internally as a template"
@@ -813,7 +844,10 @@ class QueryStringSearch(Search):
     ) -> tuple[dict[str, Any], str]:
         """Build The query string using the search parameters"""
         logger.debug("Building the query string that will be used for search")
-        query_params = format_query_params(product_type, self.config, query_dict)
+        error_context = f"Product type: {product_type} / provider : {self.provider}"
+        query_params = format_query_params(
+            product_type, self.config, query_dict, error_context
+        )
 
         # Build the final query string, in one go without quoting it
         # (some providers do not operate well with urlencoded and quoted query strings)
@@ -928,13 +962,13 @@ class QueryStringSearch(Search):
             )
             response = self._request(single_search_prep)
             next_page_url_key_path = self.config.pagination.get(
-                "next_page_url_key_path", None
+                "next_page_url_key_path"
             )
             next_page_query_obj_key_path = self.config.pagination.get(
-                "next_page_query_obj_key_path", None
+                "next_page_query_obj_key_path"
             )
             next_page_merge_key_path = self.config.pagination.get(
-                "next_page_merge_key_path", None
+                "next_page_merge_key_path"
             )
             if self.config.result_type == "xml":
                 root_node = etree.fromstring(response.content)
@@ -1089,6 +1123,8 @@ class QueryStringSearch(Search):
             product.properties = dict(
                 getattr(self.config, "product_type_config", {}), **product.properties
             )
+            additional_assets = self.get_assets_from_mapping(result)
+            product.assets.update(additional_assets)
             # move assets from properties to product's attr, normalize keys & roles
             for key, asset in product.properties.pop("assets", {}).items():
                 norm_key, asset["roles"] = product.driver.guess_asset_key_and_roles(
@@ -1173,7 +1209,8 @@ class QueryStringSearch(Search):
         collection = getattr(self.config, "collection", None)
         if collection is None:
             collection = (
-                prep.product_type_def_params.get("collection", None) or product_type
+                getattr(prep, "product_type_def_params", {}).get("collection")
+                or product_type
             )
 
         if collection is None:
@@ -1330,9 +1367,9 @@ class ODataV4Search(QueryStringSearch):
 
         # parse jsonpath on init
         metadata_pre_mapping = getattr(self.config, "metadata_pre_mapping", {})
-        metadata_path = metadata_pre_mapping.get("metadata_path", None)
-        metadata_path_id = metadata_pre_mapping.get("metadata_path_id", None)
-        metadata_path_value = metadata_pre_mapping.get("metadata_path_value", None)
+        metadata_path = metadata_pre_mapping.get("metadata_path")
+        metadata_path_id = metadata_pre_mapping.get("metadata_path_id")
+        metadata_path_value = metadata_pre_mapping.get("metadata_path_value")
         if metadata_path and metadata_path_id and metadata_path_value:
             self.config.metadata_pre_mapping["metadata_path"] = string_to_jsonpath(
                 metadata_path
@@ -1390,9 +1427,9 @@ class ODataV4Search(QueryStringSearch):
         For example, going from '$.Metadata[?(@.id="foo")].value' to '$.Metadata.foo.value'
         """
         metadata_pre_mapping = getattr(self.config, "metadata_pre_mapping", {})
-        metadata_path = metadata_pre_mapping.get("metadata_path", None)
-        metadata_path_id = metadata_pre_mapping.get("metadata_path_id", None)
-        metadata_path_value = metadata_pre_mapping.get("metadata_path_value", None)
+        metadata_path = metadata_pre_mapping.get("metadata_path")
+        metadata_path_id = metadata_pre_mapping.get("metadata_path_id")
+        metadata_path_value = metadata_pre_mapping.get("metadata_path_value")
 
         if metadata_path and metadata_path_id and metadata_path_value:
             # metadata_path already parsed on init
@@ -1479,13 +1516,17 @@ class PostJsonSearch(QueryStringSearch):
             )
 
             # Add to the query, the queryable parameters set in the provider product type definition
+            product_type_metadata_mapping = {
+                **getattr(self.config, "metadata_mapping", {}),
+                **prep.product_type_def_params.get("metadata_mapping", {}),
+            }
             keywords.update(
                 {
                     k: v
                     for k, v in prep.product_type_def_params.items()
                     if k not in keywords.keys()
-                    and k in self.config.metadata_mapping.keys()
-                    and isinstance(self.config.metadata_mapping[k], list)
+                    and k in product_type_metadata_mapping.keys()
+                    and isinstance(product_type_metadata_mapping[k], list)
                 }
             )
 
@@ -1514,10 +1555,10 @@ class PostJsonSearch(QueryStringSearch):
                 ]["results_entry"]
                 self.config.collection = self.config.products[product_type][
                     "specific_qssearch"
-                ].get("collection", None)
+                ].get("collection")
                 self.config.merge_responses = self.config.products[product_type][
                     "specific_qssearch"
-                ].get("merge_responses", None)
+                ].get("merge_responses")
 
                 def count_hits(self, *x, **y):
                     return 1
@@ -1785,7 +1826,10 @@ class StacSearch(PostJsonSearch):
             query_dict.setdefault("startTimeFromAscendingNode", "..")
             query_dict.setdefault("completionTimeFromAscendingNode", "..")
 
-        query_params = format_query_params(product_type, self.config, query_dict)
+        error_context = f"Product type: {product_type} / provider : {self.provider}"
+        query_params = format_query_params(
+            product_type, self.config, query_dict, error_context
+        )
 
         # Build the final query string, in one go without quoting it
         # (some providers do not operate well with urlencoded and quoted query strings)
@@ -1812,7 +1856,7 @@ class StacSearch(PostJsonSearch):
         ):
             raise NotImplementedError()
 
-        product_type = kwargs.get("productType", None)
+        product_type = kwargs.get("productType")
         provider_product_type = (
             self.config.products.get(product_type, {}).get("productType", product_type)
             if product_type
@@ -1896,30 +1940,46 @@ class StacSearch(PostJsonSearch):
                     "No queryable found for %s on %s", product_type, self.provider
                 )
                 return None
-
             # convert json results to pydantic model fields
             field_definitions: dict[str, Any] = dict()
+            STAC_TO_EODAG_QUERYABLES = {
+                "start_datetime": "start",
+                "end_datetime": "end",
+                "datetime": None,
+                "bbox": "geom",
+            }
             for json_param, json_mtd in json_queryables.items():
-                param = (
+                param = STAC_TO_EODAG_QUERYABLES.get(
+                    json_param,
                     get_queryable_from_provider(
                         json_param, self.get_metadata_mapping(product_type)
                     )
-                    or json_param
+                    or json_param,
                 )
+                if param is None:
+                    continue
 
-                default = kwargs.get(param, None)
+                default = kwargs.get(param, json_mtd.get("default"))
                 annotated_def = json_field_definition_to_python(
                     json_mtd, default_value=default
                 )
                 field_definitions[param] = get_args(annotated_def)
 
             python_queryables = create_model("m", **field_definitions).model_fields
-            # replace geometry by geom
             geom_queryable = python_queryables.pop("geometry", None)
             if geom_queryable:
-                python_queryables["geom"] = geom_queryable
+                python_queryables["geom"] = Queryables.model_fields["geom"]
 
-        return model_fields_to_annotated(python_queryables)
+            queryables_dict = model_fields_to_annotated(python_queryables)
+            # append "datetime" as "start" & "end" if needed
+            if "datetime" in json_queryables:
+                eodag_queryables = copy_deepcopy(
+                    model_fields_to_annotated(Queryables.model_fields)
+                )
+                queryables_dict.setdefault("start", eodag_queryables["start"])
+                queryables_dict.setdefault("end", eodag_queryables["end"])
+
+            return queryables_dict
 
 
 class PostJsonSearchWithStacQueryables(StacSearch, PostJsonSearch):
