@@ -23,6 +23,7 @@ import os
 import re
 from typing import TYPE_CHECKING, cast
 from unittest.mock import Mock
+from urllib.parse import urlencode
 
 import dateutil
 from cachetools.func import lru_cache
@@ -67,8 +68,6 @@ from eodag.utils import (
     deepcopy,
     dict_items_recursive_apply,
     format_dict_items,
-    obj_md5sum,
-    urlencode,
 )
 from eodag.utils.exceptions import (
     MisconfiguredError,
@@ -123,7 +122,7 @@ def format_product_types(product_types: list[dict[str, Any]]) -> str:
     """
     result: list[str] = []
     for pt in product_types:
-        result.append(f'* *__{pt["ID"]}__*: {pt["abstract"]}')
+        result.append(f"* *__{pt['ID']}__*: {pt['abstract']}")
     return "\n".join(sorted(result))
 
 
@@ -266,11 +265,7 @@ def download_stac_item(
             _order_and_update(product, auth, kwargs)
 
         download_stream = product.downloader._stream_download_dict(
-            product,
-            auth=auth,
-            asset=asset,
-            wait=-1,
-            timeout=-1,
+            product, auth=auth, asset=asset, wait=-1, timeout=-1
         )
     except NotImplementedError:
         logger.warning(
@@ -370,6 +365,7 @@ async def all_collections(
     instrument: Optional[str] = None,
     constellation: Optional[str] = None,
     datetime: Optional[str] = None,
+    bbox: Optional[str] = None,
 ) -> dict[str, Any]:
     """Build STAC collections
 
@@ -395,6 +391,7 @@ async def all_collections(
             instrument=instrument,
             constellation=constellation,
             datetime=datetime,
+            bbox=bbox,
         )
 
         # # parse f-strings
@@ -414,7 +411,7 @@ async def all_collections(
         return collections
 
     hashed_collections = hash(
-        f"{provider}:{q}:{platform}:{instrument}:{constellation}:{datetime}"
+        f"{provider}:{q}:{platform}:{instrument}:{constellation}:{datetime}:{bbox}"
     )
     cache_key = f"{CACHE_KEY_COLLECTIONS}:{hashed_collections}"
     return await cached(_fetch, cache_key, request)
@@ -684,7 +681,7 @@ def crunch_products(
     cruncher = crunchers.get(cruncher_name)
     if not cruncher:
         raise ValidationError(
-            f'Unknown crunch name. Use one of: {", ".join(crunchers.keys())}'
+            f"Unknown crunch name. Use one of: {', '.join(crunchers.keys())}"
         )
 
     cruncher_config: dict[str, Any] = {}
@@ -694,7 +691,7 @@ def crunch_products(
             raise ValidationError(
                 (
                     f"cruncher {cruncher} require additional parameters:"
-                    f' {", ".join(cruncher.config_params)}'
+                    f" {', '.join(cruncher.config_params)}"
                 )
             )
         cruncher_config[config_param] = config_param_value
@@ -754,12 +751,6 @@ def eodag_api_init() -> None:
             clean = {k: v for k, v in update_fields.items() if v}
             p_f.update(clean)
 
-    eodag_api.product_types_config_md5 = obj_md5sum(
-        eodag_api.product_types_config.source
-    )
-
-    eodag_api.build_index()
-
     # pre-build search plugins
     for provider in eodag_api.available_providers():
         next(eodag_api._plugins_manager.get_search_plugins(provider=provider))
