@@ -195,8 +195,8 @@ async def forward_middleware(
 ) -> Response:
     """Middleware that handles forward headers and sets request.state.url*"""
 
-    forwarded_host = request.headers.get("x-forwarded-host", None)
-    forwarded_proto = request.headers.get("x-forwarded-proto", None)
+    forwarded_host = request.headers.get("x-forwarded-host")
+    forwarded_proto = request.headers.get("x-forwarded-proto")
 
     if "forwarded" in request.headers:
         header_forwarded = parse_header(request.headers["forwarded"])
@@ -220,7 +220,7 @@ async def catalogs_root(request: Request) -> ORJSONResponse:
     response = await get_stac_catalogs(
         request=request,
         url=request.state.url,
-        provider=request.query_params.get("provider", None),
+        provider=request.query_params.get("provider"),
     )
 
     return ORJSONResponse(response)
@@ -383,24 +383,26 @@ async def list_collection_queryables(
     :returns: A json object containing the list of available queryable properties for the specified collection.
     """
     logger.info(f"{request.method} {request.state.url}")
-    # split by `,` to handle list of parameters
-    additional_params = {k: v.split(",") for k, v in dict(request.query_params).items()}
-    provider = additional_params.pop("provider", None)
 
-    datetime = additional_params.pop("datetime", None)
+    params: dict[str, list[Any]] = {}
+    for k, v in request.query_params.multi_items():
+        params.setdefault(k, []).append(v)
+
+    provider = params.pop("provider", [None])[0]
+    datetime = params.pop("datetime", [None])[0]
 
     queryables = await get_queryables(
         request,
         QueryablesGetParams.model_validate(
             {
-                **additional_params,
+                **params,
                 **{
                     "collection": collection_id,
-                    "datetime": datetime[0] if datetime else None,
+                    "datetime": datetime,
                 },
             }
         ),
-        provider=provider[0] if provider else None,
+        provider=provider,
     )
 
     return ORJSONResponse(queryables)
@@ -437,6 +439,7 @@ async def collections(
     request: Request,
     provider: Optional[str] = None,
     q: Optional[str] = None,
+    bbox: Optional[str] = None,
     platform: Optional[str] = None,
     instrument: Optional[str] = None,
     constellation: Optional[str] = None,
@@ -450,8 +453,9 @@ async def collections(
     logger.info(f"{request.method} {request.state.url}")
 
     collections = await all_collections(
-        request, provider, q, platform, instrument, constellation, datetime
+        request, provider, q, platform, instrument, constellation, datetime, bbox
     )
+
     return ORJSONResponse(collections)
 
 
