@@ -34,6 +34,7 @@ from urllib.parse import (
 
 import geojson
 from jsonpath_ng.jsonpath import Child
+from shapely.geometry import Polygon
 
 from eodag.api.product.metadata_mapping import (
     DEFAULT_METADATA_MAPPING,
@@ -41,6 +42,7 @@ from eodag.api.product.metadata_mapping import (
     get_metadata_path,
 )
 from eodag.rest.config import Settings
+from eodag.rest.types.stac_search import SearchPostRequest
 from eodag.rest.utils.rfc3339 import str_to_interval
 from eodag.utils import (
     deepcopy,
@@ -56,6 +58,7 @@ from eodag.utils.exceptions import (
     NotAvailableError,
     RequestError,
     TimeOutError,
+    ValidationError,
 )
 from eodag.utils.requests import fetch_json
 
@@ -433,14 +436,14 @@ class StacItem(StacCommon):
                     ] += f"/{asset_key}?{urlencode(query_dict, doseq=True)}"
                 else:
                     assets[asset_key]["href"] += f"/{asset_key}"
-                if asset_type := asset_value.get("type", None):
+                if asset_type := asset_value.get("type"):
                     assets[asset_key]["type"] = asset_type
                     if origin := assets[asset_key].get("alternate", {}).get("origin"):
                         origin["type"] = asset_type
                 asset_value["href"] = _quote_url_path(asset_value["href"])
 
         if thumbnail_url := product.properties.get(
-            "quicklook", product.properties.get("thumbnail", None)
+            "quicklook", product.properties.get("thumbnail")
         ):
             assets["thumbnail"] = {
                 "title": "Thumbnail",
@@ -787,10 +790,6 @@ class StacCollection(StacCommon):
                 f"Product type keywords: {str(product_type_collection['keywords'])}",
             )
 
-        # merge providers
-        if "providers" in ext_stac_collection:
-            ext_stac_collection["providers"] += product_type_collection["providers"]
-
         product_type_collection.update(ext_stac_collection)
 
         # parse f-strings
@@ -818,6 +817,7 @@ class StacCollection(StacCommon):
         instrument: Optional[str] = None,
         constellation: Optional[str] = None,
         datetime: Optional[str] = None,
+        bbox: Optional[str] = None,
     ) -> list[dict[str, Any]]:
         """Build STAC collections list
 
@@ -852,13 +852,30 @@ class StacCollection(StacCommon):
         else:
             product_types = all_pt
 
+        _bbox_poly = None
+        if bbox:
+            try:
+                _bbox = [float(x) for x in bbox.split(",")]
+                SearchPostRequest.validate_bbox(_bbox)  # type: ignore
+                _bbox_poly = Polygon.from_bounds(*_bbox)
+            except ValueError as e:
+                raise ValidationError(f"Wrong bbox: {e}")
+
         # list product types with all metadata using guessed ids
         collection_list: list[dict[str, Any]] = []
         for product_type in product_types:
             stac_collection = self.__generate_stac_collection(
                 collection_model, product_type
             )
-            collection_list.append(stac_collection)
+            # Apply bbox filter
+            if _bbox_poly:
+                _other_bbox_poly = Polygon.from_bounds(
+                    *stac_collection["extent"]["spatial"]["bbox"][0]
+                )
+                if _bbox_poly.intersects(_other_bbox_poly):
+                    collection_list.append(stac_collection)
+            else:
+                collection_list.append(stac_collection)
 
         return collection_list
 
