@@ -40,13 +40,6 @@ from tests.context import (
     uri_to_path,
 )
 
-THEIA_SEARCH_ARGS = [
-    "theia",
-    "S2_MSI_L2A_MAJA",
-    "2019-03-01",
-    "2019-03-15",
-    [0.2563590566012408, 43.19555008715042, 2.379835675499976, 43.907759172380565],
-]
 PEPS_SEARCH_ARGS = [
     "peps",
     "S2_MSI_L1C",
@@ -222,6 +215,14 @@ EUMETSAT_DS_SEARCH_ARGS = [
     [-69.3363, -75.9038, -39.3465, -68.2361],
 ]
 
+FEDEO_CEDA_SEARCH_ARGS = [
+    "fedeo_ceda",
+    "MERIS_ALAMO_L2_V2.2",
+    None,
+    None,
+    None,
+]
+
 
 @pytest.mark.enable_socket
 class EndToEndBase(unittest.TestCase):
@@ -427,12 +428,6 @@ class TestEODagEndToEnd(EndToEndBase):
         expected_filename = "{}.zip".format(product.properties["title"])
         self.execute_download(product, expected_filename)
 
-    # @unittest.skip("service unavailable for the moment")
-    def test_end_to_end_search_download_theia(self):
-        product = self.execute_search(*THEIA_SEARCH_ARGS)
-        expected_filename = "{}.zip".format(product.properties["title"])
-        self.execute_download(product, expected_filename)
-
     def test_end_to_end_search_download_geodes(self):
         product = self.execute_search(*GEODES_SEARCH_ARGS)
         expected_filename = "{}.zip".format(product.properties["title"])
@@ -465,6 +460,12 @@ class TestEODagEndToEnd(EndToEndBase):
         )
         self.execute_download(product, expected_filename)
 
+    def test_end_to_end_search_download_fedeo_ceda(self):
+        self.eodag.discover_product_types(provider="fedeo_ceda")
+        products = self.execute_search(*FEDEO_CEDA_SEARCH_ARGS, check_product=False)
+        expected_filename = "{}".format(products[2].properties["title"])
+        self.execute_download(products[2], expected_filename)
+
     def test_end_to_end_search_download_creodias_noresult(self):
         """Requesting a page on creodias with no results must return an empty SearchResult"""
         # As of 2021-03-19 this search at page 1 returns 31 products, so at page 2 there
@@ -587,7 +588,6 @@ class TestEODagEndToEnd(EndToEndBase):
         # providers supporting search-by-tile
         supported_providers_product_types = [
             ("peps", "S2_MSI_L1C"),
-            ("theia", "S2_MSI_L2A_MAJA"),
             ("planetary_computer", "S2_MSI_L2A"),
             ("earth_search", "S2_MSI_L1C"),
         ]
@@ -717,6 +717,29 @@ class TestEODagEndToEnd(EndToEndBase):
         ext_product_types_conf = self.eodag.discover_product_types(provider=provider)
         self.assertIsNone(ext_product_types_conf[provider])
 
+    def test_end_to_end_discover_product_types_fedeo_ceda(self):
+        """discover_product_types() must return an external product types configuration for fedeo ceda"""
+        provider = "fedeo_ceda"
+        ext_product_types_conf = self.eodag.discover_product_types(provider=provider)
+        self.assertEqual(
+            ext_product_types_conf[provider]["product_types_config"][
+                "MERIS_ALAMO_L2_V2.2"
+            ]["ID"],
+            "MERIS_ALAMO_L2_V2.2",
+        )
+        self.assertEqual(
+            "MERIS",
+            ext_product_types_conf[provider]["product_types_config"][
+                "MERIS_ALAMO_L2_V2.2"
+            ]["instrument"],
+        )
+        self.assertEqual(
+            "other",
+            ext_product_types_conf[provider]["product_types_config"][
+                "MERIS_ALAMO_L2_V2.2"
+            ]["license"],
+        )
+
 
 # @unittest.skip("skip auto run")
 class TestEODagEndToEndComplete(EndToEndBase):
@@ -942,11 +965,6 @@ class TestEODagEndToEndWrongCredentials(EndToEndBase):
                 os.environ.pop(k)
         os.environ.update(cls.eodag_env_backup)
 
-    def test_end_to_end_wrong_credentials_theia(self):
-        product = self.execute_search(*THEIA_SEARCH_ARGS)
-        with self.assertRaises(AuthenticationError):
-            self.eodag.download(product)
-
     def test_end_to_end_wrong_credentials_peps(self):
         product = self.execute_search(*PEPS_SEARCH_ARGS)
         with self.assertRaises(AuthenticationError):
