@@ -235,11 +235,11 @@ class TestMetadataFormatter(unittest.TestCase):
 
     def test_convert_get_group_name(self):
         to_format = (
-            "{fieldname#get_group_name((?P<this_is_foo>foo)|(?P<that_is_bar>bar))}"
+            "{fieldname#get_group_name((?P<this is foo>foo)|(?P<that_is_bar>bar))}"
         )
         self.assertEqual(
             format_metadata(to_format, fieldname="foo"),
-            "this_is_foo",
+            "this is foo",
         )
 
     def test_convert_replace_str(self):
@@ -265,6 +265,17 @@ class TestMetadataFormatter(unittest.TestCase):
         with self.assertRaises(TypeError):
             format_metadata(to_format, fieldname=123)
 
+    def test_convert_ceda_collection_name(self):
+        to_format = r"{fieldname#ceda_collection_name}"
+        self.assertEqual(
+            format_metadata(to_format, fieldname="https://bar/data/foo/v1.1"),
+            "FOO_V1.1",
+        )
+        self.assertEqual(
+            format_metadata(to_format, fieldname="NOT_AVAILABLE"),
+            "NOT_AVAILABLE",
+        )
+
     def test_convert_recursive_sub_str(self):
         to_format = r"{fieldname#recursive_sub_str(r'(.*) is (.*)',r'\1 was \2...')}"
         self.assertEqual(
@@ -306,6 +317,10 @@ class TestMetadataFormatter(unittest.TestCase):
         to_format = r"{fieldname#to_upper}"
         self.assertEqual(format_metadata(to_format, fieldname="FoO.bAr"), "FOO.BAR")
 
+    def test_convert_to_upper_empty(self):
+        to_format = r"{fieldname#to_upper}"
+        self.assertEqual(format_metadata(to_format, fieldname=None), "None")
+
     def test_convert_fake_l2a_title_from_l1c(self):
         to_format = "{fieldname#fake_l2a_title_from_l1c}"
         self.assertEqual(
